@@ -1,16 +1,16 @@
 from django import template
 
-from .. import icon
+from ..core import render_icon
 
 register = template.Library()
 
 
 @register.simple_tag(name="icon")
-def do_icon(name, *args, **kwargs):
+def icon_tag(name, *args, **kwargs):
     """
     Render an icon.
 
-    This template is an interface to the `icon` function from `django_icons`
+    This template is an interface to the `render_icon` function from `django_icons`
 
     **Tag name**::
 
@@ -41,4 +41,4 @@ def do_icon(name, *args, **kwargs):
         {% icon 'pencil' 'fa-big' %}
         {% icon 'trash' title='Delete' %}
     """
-    return icon(name, *args, **kwargs)
+    return render_icon(name, *args, **kwargs)
